rfid

package module
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 21, 2025 License: MIT Imports: 4 Imported by: 4

Documentation

Index

Constants

This section is empty.

Variables

var DeferWrap = func(ctx context.Context, err *error) {}

DeferWrap is called by library functions when returning errors to enrich them with stack trace information. By default, this is a no-op but exists so consumers of the library can BYO their own library If context is not available in a given function context.Background() will be used

var ErrorAttrs = func(err error) slog.Attr {
	return slog.String("error", err.Error())
}

Functions

func LogHex

func LogHex(key string, value []byte) slog.Attr

func Must

func Must[T any](val T, err error) T

Types

This section is empty.

Directories

Path Synopsis

Jump to